==> beagle_0.2.6.orig.tar.gz: beagle-0.2.6/BeagleClient/QueryableStatus.cs <==
//
// QueryableStatus.cs
//
// Copyright (C) 2005 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

using System;

namespace Beagle {

	public enum QueryableState {
		NotApplicable,
		Idle,
		Crawling,
		Indexing,
		Flushing
	}

	public class QueryableStatus {

		private string name;
		private int item_count = -1;
		private QueryableState state = QueryableState.NotApplicable;
		private int progress_percent = -1;
		private bool is_indexing = false;

		public string Name {
			get { return this.name; }
			set { this.name = value; }
		}

		public int ItemCount {
			get { return this.item_count; }
			set { this.item_count = value; }
		}

		public QueryableState State {
			get { return this.state; }
			set { this.state = value; }
		}

		public int ProgressPercent {
			get { return this.progress_percent; }
			set { this.progress_percent = value; }
		}

		public bool IsIndexing {
			get { return this.is_indexing; }
			set { this.is_indexing = value; }
		}
	}
}

==> beagle-0.2.12.tar.gz: beagle-0.2.12/BeagleClient/QueryableStatus.cs <==
//
// QueryableStatus.cs
//
// Copyright (C) 2005 Novell, Inc.
//

//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation
// the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the
// Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
// DEALINGS IN THE SOFTWARE.
//

using System;
using System.Xml.Serialization;

namespace Beagle {

	public enum QueryableState {
		NotApplicable,
		Idle,
		Crawling,
		Indexing,
		Flushing
	}

	public class QueryableStatus {

		private string name;
		private int item_count = -1;
		private QueryableState state = QueryableState.NotApplicable;
		private int progress_percent = -1;
		private bool is_indexing = false;

		[XmlAttribute]
		public string Name {
			get { return this.name; }
			set { this.name = value; }
		}

		[XmlAttribute]
		public int ItemCount {
			get { return this.item_count; }
			set { this.item_count = value; }
		}

		[XmlAttribute]
		public QueryableState State {
			get { return this.state; }
			set { this.state = value; }
		}

		[XmlAttribute]
		public int ProgressPercent {
			get { return this.progress_percent; }
			set { this.progress_percent = value; }
		}

		[XmlAttribute]
		public bool IsIndexing {
			get { return this.is_indexing; }
			set { this.is_indexing = value; }
		}
	}
}
